# -*- coding: utf-8 -*-
# Generated by Django 1.10.7 on 2018-06-18 08:39
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('contenttypes', '0002_remove_content_type_name'),
        ('reviews', '0011_auto_20180611_1422'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='review',
            unique_together=set([('highlight', 'content_type', 'object_id')]),
        ),
    ]
