# -*- coding: utf-8 -*-
# Generated by Django 1.10.7 on 2018-06-11 09:45
from __future__ import unicode_literals

from django.db import migrations


def set_display_date(apps, schemas):
    Review = apps.get_model('reviews', 'Review')
    for review in Review.objects.all():
        review.display_date = review.creation_date
        review.save()


class Migration(migrations.Migration):

    dependencies = [
        ('reviews', '0008_review_highlight'),
    ]

    operations = [
        migrations.RunPython(set_display_date)
    ]
