# -*- coding: utf-8 -*-
# Generated by Django 1.10.7 on 2018-06-11 09:33
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('reviews', '0005_auto_20170915_1148'),
    ]

    operations = [
        migrations.AddField(
            model_name='review',
            name='title',
            field=models.CharField(default='', max_length=300, verbose_name='Title'),
        ),
    ]
